@@ -2,7 +2,7 @@
 
 from pydantic import BaseSettings, BaseModel, ValidationError
 from pydantic.fields import ModelField
-from typing import TypeVar, Generic, Type, Union
+from typing import TypeVar, Generic, Type, Union, Mapping
 
 from patchwork.core import Component, AsyncPublisher, AsyncSubscriber
 from patchwork.core.config.providers import json_config_settings_source
@@ -17,6 +17,41 @@ class ImproperlyConfigured(Exception):
     pass
 
 
+ClassType = TypeVar("ClassType", bound=Type[object])
+
+
+class ClassConfig(Generic[ClassType]):
+
+    engine: ClassPath[ClassType]
+    options: Mapping = {}
+
+    def __init__(self, engine: ClassType, options: Mapping = None):
+        self.engine = engine
+        self.options = options or {}
+
+    @classmethod
+    def __get_validators__(cls):
+        yield cls.dependency_validator
+
+    @classmethod
+    def dependency_validator(cls, v, field: ModelField):
+        if isinstance(v, cls):
+            return v
+
+        engine_field = ModelField(name='engine', type_=ClassPath[ClassType],
+                                  class_validators=None, model_config=field.model_config)
+        engine, error = engine_field.validate(v.pop('engine', None), {}, loc='engine')
+        if error:
+            raise ValidationError([error], cls)
+
+        # TODO: it will be nice to have validate options against constructor arguments
+        opts = v
+        return cls(engine=engine.type_, options=opts)
+
+    def instantiate(self, **init_kwargs):
+        return self.engine(**self.options, **init_kwargs)
+
+
 ComponentType = TypeVar("ComponentType", bound=Type[Component])
 
 
