@@ -11,11 +11,11 @@ class Result:
     pass
 
 
-def test_function():
+def example_function():
     return Result
 
 
-async def test_coroutine():
+async def example_coroutine():
     return Result
 
 
@@ -23,13 +23,13 @@ def test_function_no_type():
     class M(BaseModel):
         path: FuncPath
 
-    m = M(path='tests.core.test_fnpath:test_function')
+    m = M(path='tests.core.test_fnpath:example_function')
     assert m.path() == Result
 
 
 def test_function_default():
     class M(BaseModel):
-        path: FuncPath = FuncPath(test_function)
+        path: FuncPath = FuncPath(example_function)
 
     m = M()
     assert m.path() == Result
@@ -40,14 +40,14 @@ async def test_coroutine_no_type():
     class M(BaseModel):
         path: FuncPath
 
-    m = M(path='tests.core.test_fnpath:test_coroutine')
+    m = M(path='tests.core.test_fnpath:example_coroutine')
     assert await m.path() == Result
 
 
 @pytest.mark.asyncio
 async def test_coroutine_default():
     class M(BaseModel):
-        path: FuncPath = FuncPath(test_coroutine)
+        path: FuncPath = FuncPath(example_coroutine)
 
     m = M()
     assert await m.path() == Result
\ No newline at end of file
